@@ -14,6 +14,7 @@ Usage::
 import sys
 from typing import Any, Dict, List, Type, overload
 
+from botocore.client import ClientMeta
 from botocore.exceptions import ClientError as Boto3ClientError
 from botocore.paginate import Paginator as Boto3Paginator
 
@@ -150,28 +151,29 @@ class Exceptions:
 
 class Route53Client:
     """
-    [Route53.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/route53.html#Route53.Client)
+    [Route53.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/route53.html#Route53.Client)
     """
 
+    meta: ClientMeta
     exceptions: Exceptions
 
     def associate_vpc_with_hosted_zone(
         self, HostedZoneId: str, VPC: "VPCTypeDef", Comment: str = None
     ) -> AssociateVPCWithHostedZoneResponseTypeDef:
         """
-        [Client.associate_vpc_with_hosted_zone documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/route53.html#Route53.Client.associate_vpc_with_hosted_zone)
+        [Client.associate_vpc_with_hosted_zone documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/route53.html#Route53.Client.associate_vpc_with_hosted_zone)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/route53.html#Route53.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/route53.html#Route53.Client.can_paginate)
         """
 
     def change_resource_record_sets(
         self, HostedZoneId: str, ChangeBatch: ChangeBatchTypeDef
     ) -> ChangeResourceRecordSetsResponseTypeDef:
         """
-        [Client.change_resource_record_sets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/route53.html#Route53.Client.change_resource_record_sets)
+        [Client.change_resource_record_sets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/route53.html#Route53.Client.change_resource_record_sets)
         """
 
     def change_tags_for_resource(
@@ -182,14 +184,14 @@ class Route53Client:
         RemoveTagKeys: List[str] = None,
     ) -> Dict[str, Any]:
         """
-        [Client.change_tags_for_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/route53.html#Route53.Client.change_tags_for_resource)
+        [Client.change_tags_for_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/route53.html#Route53.Client.change_tags_for_resource)
         """
 
     def create_health_check(
         self, CallerReference: str, HealthCheckConfig: "HealthCheckConfigTypeDef"
     ) -> CreateHealthCheckResponseTypeDef:
         """
-        [Client.create_health_check documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/route53.html#Route53.Client.create_health_check)
+        [Client.create_health_check documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/route53.html#Route53.Client.create_health_check)
         """
 
     def create_hosted_zone(
@@ -201,28 +203,28 @@ class Route53Client:
         DelegationSetId: str = None,
     ) -> CreateHostedZoneResponseTypeDef:
         """
-        [Client.create_hosted_zone documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/route53.html#Route53.Client.create_hosted_zone)
+        [Client.create_hosted_zone documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/route53.html#Route53.Client.create_hosted_zone)
         """
 
     def create_query_logging_config(
         self, HostedZoneId: str, CloudWatchLogsLogGroupArn: str
     ) -> CreateQueryLoggingConfigResponseTypeDef:
         """
-        [Client.create_query_logging_config documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/route53.html#Route53.Client.create_query_logging_config)
+        [Client.create_query_logging_config documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/route53.html#Route53.Client.create_query_logging_config)
         """
 
     def create_reusable_delegation_set(
         self, CallerReference: str, HostedZoneId: str = None
     ) -> CreateReusableDelegationSetResponseTypeDef:
         """
-        [Client.create_reusable_delegation_set documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/route53.html#Route53.Client.create_reusable_delegation_set)
+        [Client.create_reusable_delegation_set documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/route53.html#Route53.Client.create_reusable_delegation_set)
         """
 
     def create_traffic_policy(
         self, Name: str, Document: str, Comment: str = None
     ) -> CreateTrafficPolicyResponseTypeDef:
         """
-        [Client.create_traffic_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/route53.html#Route53.Client.create_traffic_policy)
+        [Client.create_traffic_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/route53.html#Route53.Client.create_traffic_policy)
         """
 
     def create_traffic_policy_instance(
@@ -234,65 +236,65 @@ class Route53Client:
         TrafficPolicyVersion: int,
     ) -> CreateTrafficPolicyInstanceResponseTypeDef:
         """
-        [Client.create_traffic_policy_instance documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/route53.html#Route53.Client.create_traffic_policy_instance)
+        [Client.create_traffic_policy_instance documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/route53.html#Route53.Client.create_traffic_policy_instance)
         """
 
     def create_traffic_policy_version(
         self, Id: str, Document: str, Comment: str = None
     ) -> CreateTrafficPolicyVersionResponseTypeDef:
         """
-        [Client.create_traffic_policy_version documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/route53.html#Route53.Client.create_traffic_policy_version)
+        [Client.create_traffic_policy_version documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/route53.html#Route53.Client.create_traffic_policy_version)
         """
 
     def create_vpc_association_authorization(
         self, HostedZoneId: str, VPC: "VPCTypeDef"
     ) -> CreateVPCAssociationAuthorizationResponseTypeDef:
         """
-        [Client.create_vpc_association_authorization documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/route53.html#Route53.Client.create_vpc_association_authorization)
+        [Client.create_vpc_association_authorization documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/route53.html#Route53.Client.create_vpc_association_authorization)
         """
 
     def delete_health_check(self, HealthCheckId: str) -> Dict[str, Any]:
         """
-        [Client.delete_health_check documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/route53.html#Route53.Client.delete_health_check)
+        [Client.delete_health_check documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/route53.html#Route53.Client.delete_health_check)
         """
 
     def delete_hosted_zone(self, Id: str) -> DeleteHostedZoneResponseTypeDef:
         """
-        [Client.delete_hosted_zone documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/route53.html#Route53.Client.delete_hosted_zone)
+        [Client.delete_hosted_zone documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/route53.html#Route53.Client.delete_hosted_zone)
         """
 
     def delete_query_logging_config(self, Id: str) -> Dict[str, Any]:
         """
-        [Client.delete_query_logging_config documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/route53.html#Route53.Client.delete_query_logging_config)
+        [Client.delete_query_logging_config documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/route53.html#Route53.Client.delete_query_logging_config)
         """
 
     def delete_reusable_delegation_set(self, Id: str) -> Dict[str, Any]:
         """
-        [Client.delete_reusable_delegation_set documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/route53.html#Route53.Client.delete_reusable_delegation_set)
+        [Client.delete_reusable_delegation_set documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/route53.html#Route53.Client.delete_reusable_delegation_set)
         """
 
     def delete_traffic_policy(self, Id: str, Version: int) -> Dict[str, Any]:
         """
-        [Client.delete_traffic_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/route53.html#Route53.Client.delete_traffic_policy)
+        [Client.delete_traffic_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/route53.html#Route53.Client.delete_traffic_policy)
         """
 
     def delete_traffic_policy_instance(self, Id: str) -> Dict[str, Any]:
         """
-        [Client.delete_traffic_policy_instance documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/route53.html#Route53.Client.delete_traffic_policy_instance)
+        [Client.delete_traffic_policy_instance documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/route53.html#Route53.Client.delete_traffic_policy_instance)
         """
 
     def delete_vpc_association_authorization(
         self, HostedZoneId: str, VPC: "VPCTypeDef"
     ) -> Dict[str, Any]:
         """
-        [Client.delete_vpc_association_authorization documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/route53.html#Route53.Client.delete_vpc_association_authorization)
+        [Client.delete_vpc_association_authorization documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/route53.html#Route53.Client.delete_vpc_association_authorization)
         """
 
     def disassociate_vpc_from_hosted_zone(
         self, HostedZoneId: str, VPC: "VPCTypeDef", Comment: str = None
     ) -> DisassociateVPCFromHostedZoneResponseTypeDef:
         """
-        [Client.disassociate_vpc_from_hosted_zone documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/route53.html#Route53.Client.disassociate_vpc_from_hosted_zone)
+        [Client.disassociate_vpc_from_hosted_zone documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/route53.html#Route53.Client.disassociate_vpc_from_hosted_zone)
         """
 
     def generate_presigned_url(
@@ -303,7 +305,7 @@ class Route53Client:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/route53.html#Route53.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/route53.html#Route53.Client.generate_presigned_url)
         """
 
     def get_account_limit(
@@ -317,95 +319,95 @@ class Route53Client:
         ],
     ) -> GetAccountLimitResponseTypeDef:
         """
-        [Client.get_account_limit documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/route53.html#Route53.Client.get_account_limit)
+        [Client.get_account_limit documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/route53.html#Route53.Client.get_account_limit)
         """
 
     def get_change(self, Id: str) -> GetChangeResponseTypeDef:
         """
-        [Client.get_change documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/route53.html#Route53.Client.get_change)
+        [Client.get_change documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/route53.html#Route53.Client.get_change)
         """
 
     def get_checker_ip_ranges(self) -> GetCheckerIpRangesResponseTypeDef:
         """
-        [Client.get_checker_ip_ranges documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/route53.html#Route53.Client.get_checker_ip_ranges)
+        [Client.get_checker_ip_ranges documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/route53.html#Route53.Client.get_checker_ip_ranges)
         """
 
     def get_geo_location(
         self, ContinentCode: str = None, CountryCode: str = None, SubdivisionCode: str = None
     ) -> GetGeoLocationResponseTypeDef:
         """
-        [Client.get_geo_location documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/route53.html#Route53.Client.get_geo_location)
+        [Client.get_geo_location documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/route53.html#Route53.Client.get_geo_location)
         """
 
     def get_health_check(self, HealthCheckId: str) -> GetHealthCheckResponseTypeDef:
         """
-        [Client.get_health_check documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/route53.html#Route53.Client.get_health_check)
+        [Client.get_health_check documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/route53.html#Route53.Client.get_health_check)
         """
 
     def get_health_check_count(self) -> GetHealthCheckCountResponseTypeDef:
         """
-        [Client.get_health_check_count documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/route53.html#Route53.Client.get_health_check_count)
+        [Client.get_health_check_count documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/route53.html#Route53.Client.get_health_check_count)
         """
 
     def get_health_check_last_failure_reason(
         self, HealthCheckId: str
     ) -> GetHealthCheckLastFailureReasonResponseTypeDef:
         """
-        [Client.get_health_check_last_failure_reason documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/route53.html#Route53.Client.get_health_check_last_failure_reason)
+        [Client.get_health_check_last_failure_reason documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/route53.html#Route53.Client.get_health_check_last_failure_reason)
         """
 
     def get_health_check_status(self, HealthCheckId: str) -> GetHealthCheckStatusResponseTypeDef:
         """
-        [Client.get_health_check_status documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/route53.html#Route53.Client.get_health_check_status)
+        [Client.get_health_check_status documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/route53.html#Route53.Client.get_health_check_status)
         """
 
     def get_hosted_zone(self, Id: str) -> GetHostedZoneResponseTypeDef:
         """
-        [Client.get_hosted_zone documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/route53.html#Route53.Client.get_hosted_zone)
+        [Client.get_hosted_zone documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/route53.html#Route53.Client.get_hosted_zone)
         """
 
     def get_hosted_zone_count(self) -> GetHostedZoneCountResponseTypeDef:
         """
-        [Client.get_hosted_zone_count documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/route53.html#Route53.Client.get_hosted_zone_count)
+        [Client.get_hosted_zone_count documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/route53.html#Route53.Client.get_hosted_zone_count)
         """
 
     def get_hosted_zone_limit(
         self, Type: Literal["MAX_RRSETS_BY_ZONE", "MAX_VPCS_ASSOCIATED_BY_ZONE"], HostedZoneId: str
     ) -> GetHostedZoneLimitResponseTypeDef:
         """
-        [Client.get_hosted_zone_limit documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/route53.html#Route53.Client.get_hosted_zone_limit)
+        [Client.get_hosted_zone_limit documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/route53.html#Route53.Client.get_hosted_zone_limit)
         """
 
     def get_query_logging_config(self, Id: str) -> GetQueryLoggingConfigResponseTypeDef:
         """
-        [Client.get_query_logging_config documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/route53.html#Route53.Client.get_query_logging_config)
+        [Client.get_query_logging_config documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/route53.html#Route53.Client.get_query_logging_config)
         """
 
     def get_reusable_delegation_set(self, Id: str) -> GetReusableDelegationSetResponseTypeDef:
         """
-        [Client.get_reusable_delegation_set documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/route53.html#Route53.Client.get_reusable_delegation_set)
+        [Client.get_reusable_delegation_set documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/route53.html#Route53.Client.get_reusable_delegation_set)
         """
 
     def get_reusable_delegation_set_limit(
         self, Type: Literal["MAX_ZONES_BY_REUSABLE_DELEGATION_SET"], DelegationSetId: str
     ) -> GetReusableDelegationSetLimitResponseTypeDef:
         """
-        [Client.get_reusable_delegation_set_limit documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/route53.html#Route53.Client.get_reusable_delegation_set_limit)
+        [Client.get_reusable_delegation_set_limit documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/route53.html#Route53.Client.get_reusable_delegation_set_limit)
         """
 
     def get_traffic_policy(self, Id: str, Version: int) -> GetTrafficPolicyResponseTypeDef:
         """
-        [Client.get_traffic_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/route53.html#Route53.Client.get_traffic_policy)
+        [Client.get_traffic_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/route53.html#Route53.Client.get_traffic_policy)
         """
 
     def get_traffic_policy_instance(self, Id: str) -> GetTrafficPolicyInstanceResponseTypeDef:
         """
-        [Client.get_traffic_policy_instance documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/route53.html#Route53.Client.get_traffic_policy_instance)
+        [Client.get_traffic_policy_instance documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/route53.html#Route53.Client.get_traffic_policy_instance)
         """
 
     def get_traffic_policy_instance_count(self) -> GetTrafficPolicyInstanceCountResponseTypeDef:
         """
-        [Client.get_traffic_policy_instance_count documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/route53.html#Route53.Client.get_traffic_policy_instance_count)
+        [Client.get_traffic_policy_instance_count documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/route53.html#Route53.Client.get_traffic_policy_instance_count)
         """
 
     def list_geo_locations(
@@ -416,28 +418,28 @@ class Route53Client:
         MaxItems: str = None,
     ) -> ListGeoLocationsResponseTypeDef:
         """
-        [Client.list_geo_locations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/route53.html#Route53.Client.list_geo_locations)
+        [Client.list_geo_locations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/route53.html#Route53.Client.list_geo_locations)
         """
 
     def list_health_checks(
         self, Marker: str = None, MaxItems: str = None
     ) -> ListHealthChecksResponseTypeDef:
         """
-        [Client.list_health_checks documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/route53.html#Route53.Client.list_health_checks)
+        [Client.list_health_checks documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/route53.html#Route53.Client.list_health_checks)
         """
 
     def list_hosted_zones(
         self, Marker: str = None, MaxItems: str = None, DelegationSetId: str = None
     ) -> ListHostedZonesResponseTypeDef:
         """
-        [Client.list_hosted_zones documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/route53.html#Route53.Client.list_hosted_zones)
+        [Client.list_hosted_zones documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/route53.html#Route53.Client.list_hosted_zones)
         """
 
     def list_hosted_zones_by_name(
         self, DNSName: str = None, HostedZoneId: str = None, MaxItems: str = None
     ) -> ListHostedZonesByNameResponseTypeDef:
         """
-        [Client.list_hosted_zones_by_name documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/route53.html#Route53.Client.list_hosted_zones_by_name)
+        [Client.list_hosted_zones_by_name documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/route53.html#Route53.Client.list_hosted_zones_by_name)
         """
 
     def list_hosted_zones_by_vpc(
@@ -475,14 +477,14 @@ class Route53Client:
         NextToken: str = None,
     ) -> ListHostedZonesByVPCResponseTypeDef:
         """
-        [Client.list_hosted_zones_by_vpc documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/route53.html#Route53.Client.list_hosted_zones_by_vpc)
+        [Client.list_hosted_zones_by_vpc documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/route53.html#Route53.Client.list_hosted_zones_by_vpc)
         """
 
     def list_query_logging_configs(
         self, HostedZoneId: str = None, NextToken: str = None, MaxResults: str = None
     ) -> ListQueryLoggingConfigsResponseTypeDef:
         """
-        [Client.list_query_logging_configs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/route53.html#Route53.Client.list_query_logging_configs)
+        [Client.list_query_logging_configs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/route53.html#Route53.Client.list_query_logging_configs)
         """
 
     def list_resource_record_sets(
@@ -496,35 +498,35 @@ class Route53Client:
         MaxItems: str = None,
     ) -> ListResourceRecordSetsResponseTypeDef:
         """
-        [Client.list_resource_record_sets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/route53.html#Route53.Client.list_resource_record_sets)
+        [Client.list_resource_record_sets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/route53.html#Route53.Client.list_resource_record_sets)
         """
 
     def list_reusable_delegation_sets(
         self, Marker: str = None, MaxItems: str = None
     ) -> ListReusableDelegationSetsResponseTypeDef:
         """
-        [Client.list_reusable_delegation_sets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/route53.html#Route53.Client.list_reusable_delegation_sets)
+        [Client.list_reusable_delegation_sets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/route53.html#Route53.Client.list_reusable_delegation_sets)
         """
 
     def list_tags_for_resource(
         self, ResourceType: Literal["healthcheck", "hostedzone"], ResourceId: str
     ) -> ListTagsForResourceResponseTypeDef:
         """
-        [Client.list_tags_for_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/route53.html#Route53.Client.list_tags_for_resource)
+        [Client.list_tags_for_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/route53.html#Route53.Client.list_tags_for_resource)
         """
 
     def list_tags_for_resources(
         self, ResourceType: Literal["healthcheck", "hostedzone"], ResourceIds: List[str]
     ) -> ListTagsForResourcesResponseTypeDef:
         """
-        [Client.list_tags_for_resources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/route53.html#Route53.Client.list_tags_for_resources)
+        [Client.list_tags_for_resources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/route53.html#Route53.Client.list_tags_for_resources)
         """
 
     def list_traffic_policies(
         self, TrafficPolicyIdMarker: str = None, MaxItems: str = None
     ) -> ListTrafficPoliciesResponseTypeDef:
         """
-        [Client.list_traffic_policies documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/route53.html#Route53.Client.list_traffic_policies)
+        [Client.list_traffic_policies documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/route53.html#Route53.Client.list_traffic_policies)
         """
 
     def list_traffic_policy_instances(
@@ -537,7 +539,7 @@ class Route53Client:
         MaxItems: str = None,
     ) -> ListTrafficPolicyInstancesResponseTypeDef:
         """
-        [Client.list_traffic_policy_instances documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/route53.html#Route53.Client.list_traffic_policy_instances)
+        [Client.list_traffic_policy_instances documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/route53.html#Route53.Client.list_traffic_policy_instances)
         """
 
     def list_traffic_policy_instances_by_hosted_zone(
@@ -550,7 +552,7 @@ class Route53Client:
         MaxItems: str = None,
     ) -> ListTrafficPolicyInstancesByHostedZoneResponseTypeDef:
         """
-        [Client.list_traffic_policy_instances_by_hosted_zone documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/route53.html#Route53.Client.list_traffic_policy_instances_by_hosted_zone)
+        [Client.list_traffic_policy_instances_by_hosted_zone documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/route53.html#Route53.Client.list_traffic_policy_instances_by_hosted_zone)
         """
 
     def list_traffic_policy_instances_by_policy(
@@ -565,21 +567,21 @@ class Route53Client:
         MaxItems: str = None,
     ) -> ListTrafficPolicyInstancesByPolicyResponseTypeDef:
         """
-        [Client.list_traffic_policy_instances_by_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/route53.html#Route53.Client.list_traffic_policy_instances_by_policy)
+        [Client.list_traffic_policy_instances_by_policy documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/route53.html#Route53.Client.list_traffic_policy_instances_by_policy)
         """
 
     def list_traffic_policy_versions(
         self, Id: str, TrafficPolicyVersionMarker: str = None, MaxItems: str = None
     ) -> ListTrafficPolicyVersionsResponseTypeDef:
         """
-        [Client.list_traffic_policy_versions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/route53.html#Route53.Client.list_traffic_policy_versions)
+        [Client.list_traffic_policy_versions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/route53.html#Route53.Client.list_traffic_policy_versions)
         """
 
     def list_vpc_association_authorizations(
         self, HostedZoneId: str, NextToken: str = None, MaxResults: str = None
     ) -> ListVPCAssociationAuthorizationsResponseTypeDef:
         """
-        [Client.list_vpc_association_authorizations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/route53.html#Route53.Client.list_vpc_association_authorizations)
+        [Client.list_vpc_association_authorizations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/route53.html#Route53.Client.list_vpc_association_authorizations)
         """
 
     def test_dns_answer(
@@ -594,7 +596,7 @@ class Route53Client:
         EDNS0ClientSubnetMask: str = None,
     ) -> TestDNSAnswerResponseTypeDef:
         """
-        [Client.test_dns_answer documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/route53.html#Route53.Client.test_dns_answer)
+        [Client.test_dns_answer documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/route53.html#Route53.Client.test_dns_answer)
         """
 
     def update_health_check(
@@ -631,28 +633,28 @@ class Route53Client:
         ] = None,
     ) -> UpdateHealthCheckResponseTypeDef:
         """
-        [Client.update_health_check documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/route53.html#Route53.Client.update_health_check)
+        [Client.update_health_check documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/route53.html#Route53.Client.update_health_check)
         """
 
     def update_hosted_zone_comment(
         self, Id: str, Comment: str = None
     ) -> UpdateHostedZoneCommentResponseTypeDef:
         """
-        [Client.update_hosted_zone_comment documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/route53.html#Route53.Client.update_hosted_zone_comment)
+        [Client.update_hosted_zone_comment documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/route53.html#Route53.Client.update_hosted_zone_comment)
         """
 
     def update_traffic_policy_comment(
         self, Id: str, Version: int, Comment: str
     ) -> UpdateTrafficPolicyCommentResponseTypeDef:
         """
-        [Client.update_traffic_policy_comment documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/route53.html#Route53.Client.update_traffic_policy_comment)
+        [Client.update_traffic_policy_comment documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/route53.html#Route53.Client.update_traffic_policy_comment)
         """
 
     def update_traffic_policy_instance(
         self, Id: str, TTL: int, TrafficPolicyId: str, TrafficPolicyVersion: int
     ) -> UpdateTrafficPolicyInstanceResponseTypeDef:
         """
-        [Client.update_traffic_policy_instance documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/route53.html#Route53.Client.update_traffic_policy_instance)
+        [Client.update_traffic_policy_instance documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/route53.html#Route53.Client.update_traffic_policy_instance)
         """
 
     @overload
@@ -660,7 +662,7 @@ class Route53Client:
         self, operation_name: Literal["list_health_checks"]
     ) -> ListHealthChecksPaginator:
         """
-        [Paginator.ListHealthChecks documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/route53.html#Route53.Paginator.ListHealthChecks)
+        [Paginator.ListHealthChecks documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/route53.html#Route53.Paginator.ListHealthChecks)
         """
 
     @overload
@@ -668,7 +670,7 @@ class Route53Client:
         self, operation_name: Literal["list_hosted_zones"]
     ) -> ListHostedZonesPaginator:
         """
-        [Paginator.ListHostedZones documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/route53.html#Route53.Paginator.ListHostedZones)
+        [Paginator.ListHostedZones documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/route53.html#Route53.Paginator.ListHostedZones)
         """
 
     @overload
@@ -676,7 +678,7 @@ class Route53Client:
         self, operation_name: Literal["list_query_logging_configs"]
     ) -> ListQueryLoggingConfigsPaginator:
         """
-        [Paginator.ListQueryLoggingConfigs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/route53.html#Route53.Paginator.ListQueryLoggingConfigs)
+        [Paginator.ListQueryLoggingConfigs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/route53.html#Route53.Paginator.ListQueryLoggingConfigs)
         """
 
     @overload
@@ -684,7 +686,7 @@ class Route53Client:
         self, operation_name: Literal["list_resource_record_sets"]
     ) -> ListResourceRecordSetsPaginator:
         """
-        [Paginator.ListResourceRecordSets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/route53.html#Route53.Paginator.ListResourceRecordSets)
+        [Paginator.ListResourceRecordSets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/route53.html#Route53.Paginator.ListResourceRecordSets)
         """
 
     @overload
@@ -692,7 +694,7 @@ class Route53Client:
         self, operation_name: Literal["list_vpc_association_authorizations"]
     ) -> ListVPCAssociationAuthorizationsPaginator:
         """
-        [Paginator.ListVPCAssociationAuthorizations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/route53.html#Route53.Paginator.ListVPCAssociationAuthorizations)
+        [Paginator.ListVPCAssociationAuthorizations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/route53.html#Route53.Paginator.ListVPCAssociationAuthorizations)
         """
 
     def get_paginator(self, operation_name: str) -> Boto3Paginator:
@@ -702,5 +704,5 @@ class Route53Client:
         self, waiter_name: Literal["resource_record_sets_changed"]
     ) -> ResourceRecordSetsChangedWaiter:
         """
-        [Waiter.ResourceRecordSetsChanged documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.41/reference/services/route53.html#Route53.Waiter.ResourceRecordSetsChanged)
+        [Waiter.ResourceRecordSetsChanged documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.51/reference/services/route53.html#Route53.Waiter.ResourceRecordSetsChanged)
         """
